@@ -5,11 +5,6 @@ SPDX-License-Identifier: MIT-0
 
 from __future__ import annotations
 
-from typing import Any
-
-import regex as re
-
-from cfnlint.jsonschema import Validator
 from cfnlint.rules.formats.FormatKeyword import FormatKeyword
 
 
@@ -21,13 +16,7 @@ class SubnetId(FormatKeyword):
     source_url = "https://github.com/aws-cloudformation/cfn-lint/blob/main/docs/format_keyword.md#AWS::EC2::Subnet.Id"
 
     def __init__(self):
-        super().__init__(format="AWS::EC2::Subnet.Id")
-
-    def format(self, validator: Validator, instance: Any) -> bool:
-        if not isinstance(instance, str):
-            return True
-
-        if re.match(r"^subnet-(([0-9A-Fa-f]{8})|([0-9A-Fa-f]{17}))$", instance):
-            return True
-
-        return False
+        super().__init__(
+            format="AWS::EC2::Subnet.Id",
+            pattern=r"^subnet-(([0-9A-Fa-f]{8})|([0-9A-Fa-f]{17}))$",
+        )
